package de.fitko.fitconnect;

import de.fitko.fitconnect.api.domain.model.metadata.attachment.Attachment;
import de.fitko.fitconnect.api.domain.model.submission.SubmissionForPickup;
import de.fitko.fitconnect.client.factory.ClientFactory;

import java.util.Collections;
import java.util.List;
import java.util.Optional;
import java.util.UUID;

public class TestRunner {

    public static void main(final String[] args) {
        senderSample();
        subscriberSample();
    }

    private static void senderSample() {
        final var destinationId = UUID.randomUUID();

        // Without data
        ClientFactory.senderClient()
                .withDestination(destinationId)
                .withAttachments(Collections.emptyList())
                .submit();

        // With data
        ClientFactory.senderClient()
                .withDestination(destinationId)
                .withAttachments(Collections.emptyList())
                .withData("some json or xml")
                .submit();
    }

    private static void subscriberSample() {

        final var destinationId = UUID.randomUUID();

        final var client = ClientFactory.subscriberClient();
        final var submissions = client.getAvailableSubmissions(destinationId);
        final List<Attachment> attachments = client
                .requestSubmission(getFirstSubmission(submissions))
                .getAttachments();
    }

    private static UUID getFirstSubmission(final List<SubmissionForPickup> submissions) {
        final Optional<SubmissionForPickup> submission = submissions.stream().findFirst();
        return submission.isPresent() ? submission.get().getSubmissionId() : null;
    }

}
