package de.fitko.fitconnect.client.di;

import com.google.inject.Guice;
import com.google.inject.Injector;
import com.google.inject.Key;
import com.google.inject.name.Names;
import de.fitko.fitconnect.dependency.SdkModule;

/**
 * Abstract client that bootstraps the sdk´s dependency module and provides access to services and named properties.
 */
public abstract class Client {

    private static final Injector injector = Guice.createInjector(new SdkModule());

    /**
     * Get implementation for a service interface.
     *
     * @param clazz class of interface
     * @param <T> type of class interface
     * @return implementation for the given service interface
     */
    static <T> T getService(final Class<T> clazz){
        return injector.getInstance(clazz);
    }

    /**
     * Get configuration property.
     *
     * @param propertyName name of the config property
     * @return value of the named config property
     */
    static String getProperty(final String propertyName){
        return injector.getInstance(Key.get(String.class, Names.named(propertyName)));
    }
}
